Struct const_identify::OrderedIdArray
source · pub struct OrderedIdArray<const SIZE: usize> { /* private fields */ }Expand description
An array of ConstId structs that is guaranteed to be in sorted order.
Implementations
sourceimpl<const SIZE: usize> OrderedIdArray<SIZE>
impl<const SIZE: usize> OrderedIdArray<SIZE>
sourcepub const fn new(ids: [ConstId; SIZE]) -> Self
pub const fn new(ids: [ConstId; SIZE]) -> Self
Returns a new ordered array containing the sorted version of ids.
sourcepub const fn as_raw_slice(&self) -> &[ConstId]
pub const fn as_raw_slice(&self) -> &[ConstId]
Returns the underlying id slice.
sourcepub const fn as_slice(&self) -> OrderedIdSlice<'_>
pub const fn as_slice(&self) -> OrderedIdSlice<'_>
Returns an OrderedIdSlice with this arrays content.
sourcepub const fn into_raw(self) -> [ConstId; SIZE]
pub const fn into_raw(self) -> [ConstId; SIZE]
Consumes self and returns the underlying id array
sourcepub const fn into_unique(self) -> Result<UniqueIdArray<SIZE>, Self>
pub const fn into_unique(self) -> Result<UniqueIdArray<SIZE>, Self>
Consumes self and returns a UniqueIdArray.
Returns Err(Self) if the items in this array contains duplicates
sourcepub const fn const_cmp_ordered<const SIZE2: usize>(
&self,
other: &OrderedIdArray<SIZE2>
) -> Ordering
pub const fn const_cmp_ordered<const SIZE2: usize>( &self, other: &OrderedIdArray<SIZE2> ) -> Ordering
Returns the ordering between self and other
sourcepub const fn const_cmp_ordered_slice(
&self,
other: &OrderedIdSlice<'_>
) -> Ordering
pub const fn const_cmp_ordered_slice( &self, other: &OrderedIdSlice<'_> ) -> Ordering
Returns the ordering between self and other
sourcepub const fn const_cmp_unique<const SIZE2: usize>(
&self,
other: &UniqueIdArray<SIZE2>
) -> Ordering
pub const fn const_cmp_unique<const SIZE2: usize>( &self, other: &UniqueIdArray<SIZE2> ) -> Ordering
Returns the ordering between self and other
sourcepub const fn const_cmp_unique_slice(
&self,
other: &UniqueIdSlice<'_>
) -> Ordering
pub const fn const_cmp_unique_slice( &self, other: &UniqueIdSlice<'_> ) -> Ordering
Returns the ordering between self and other