Struct const_identify::UniqueIdArray
source · pub struct UniqueIdArray<const SIZE: usize> { /* private fields */ }Expand description
An array of ConstId structs that are guaranteed to be unique and in sorted order.
Implementations
sourceimpl<const SIZE: usize> UniqueIdArray<SIZE>
impl<const SIZE: usize> UniqueIdArray<SIZE>
sourcepub const fn new(ids: [ConstId; SIZE]) -> Option<Self>
pub const fn new(ids: [ConstId; SIZE]) -> Option<Self>
Returns a new unique and sorted array containing the sorted version of ids.
Returns None if the ids contains duplicates.
sourcepub const fn as_raw_slice(&self) -> &[ConstId]
pub const fn as_raw_slice(&self) -> &[ConstId]
Returns the underlying id slice.
sourcepub const fn as_slice(&self) -> UniqueIdSlice<'_>
pub const fn as_slice(&self) -> UniqueIdSlice<'_>
Returns a UniqueIdSlice with this arrays content.
sourcepub const fn into_raw(&self) -> [ConstId; SIZE]
pub const fn into_raw(&self) -> [ConstId; SIZE]
Consumes self and returns the underlying id array
sourcepub const fn into_ordered(&self) -> OrderedIdArray<SIZE>
pub const fn into_ordered(&self) -> OrderedIdArray<SIZE>
Consumes self and returns an OrderedIdArray.
sourcepub const fn const_cmp_ordered<const SIZE2: usize>(
&self,
other: &OrderedIdArray<SIZE2>
) -> Ordering
pub const fn const_cmp_ordered<const SIZE2: usize>( &self, other: &OrderedIdArray<SIZE2> ) -> Ordering
Returns the ordering between self and other
sourcepub const fn const_cmp_ordered_slice(
&self,
other: &OrderedIdSlice<'_>
) -> Ordering
pub const fn const_cmp_ordered_slice( &self, other: &OrderedIdSlice<'_> ) -> Ordering
Returns the ordering between self and other
sourcepub const fn const_cmp_unique<const SIZE2: usize>(
&self,
other: &UniqueIdArray<SIZE2>
) -> Ordering
pub const fn const_cmp_unique<const SIZE2: usize>( &self, other: &UniqueIdArray<SIZE2> ) -> Ordering
Returns the ordering between self and other
sourcepub const fn const_cmp_unique_slice(
&self,
other: &UniqueIdSlice<'_>
) -> Ordering
pub const fn const_cmp_unique_slice( &self, other: &UniqueIdSlice<'_> ) -> Ordering
Returns the ordering between self and other