Struct const_identify::UniqueIdSlice
source · pub struct UniqueIdSlice<'a> { /* private fields */ }Expand description
An unsized slice of ConstId structs that are guaranteed to be unique and in sorted order.
Implementations
sourceimpl<'a> UniqueIdSlice<'a>
impl<'a> UniqueIdSlice<'a>
sourcepub const fn from_arr<const SIZE: usize>(arr: &'a UniqueIdArray<SIZE>) -> Self
pub const fn from_arr<const SIZE: usize>(arr: &'a UniqueIdArray<SIZE>) -> Self
Creates a new slice out of the data in arr.
sourcepub const fn as_raw_slice(&self) -> &[ConstId]
pub const fn as_raw_slice(&self) -> &[ConstId]
Returns the underlying slice.
sourcepub const fn const_cmp_ordered<const SIZE2: usize>(
&self,
other: &OrderedIdArray<SIZE2>
) -> Ordering
pub const fn const_cmp_ordered<const SIZE2: usize>( &self, other: &OrderedIdArray<SIZE2> ) -> Ordering
Returns the ordering between self and other
sourcepub const fn const_cmp_ordered_slice(
&self,
other: &OrderedIdSlice<'_>
) -> Ordering
pub const fn const_cmp_ordered_slice( &self, other: &OrderedIdSlice<'_> ) -> Ordering
Returns the ordering between self and other
sourcepub const fn const_cmp_unique<const SIZE2: usize>(
&self,
other: &UniqueIdArray<SIZE2>
) -> Ordering
pub const fn const_cmp_unique<const SIZE2: usize>( &self, other: &UniqueIdArray<SIZE2> ) -> Ordering
Returns the ordering between self and other
sourcepub const fn const_cmp_unique_slice(
&self,
other: &UniqueIdSlice<'_>
) -> Ordering
pub const fn const_cmp_unique_slice( &self, other: &UniqueIdSlice<'_> ) -> Ordering
Returns the ordering between self and other